"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const schematics_1 = require("@angular-devkit/schematics");
const tasks_1 = require("@angular-devkit/schematics/tasks");
const config_1 = require("@schematics/angular/utility/config");
const schematics_2 = require("@angular/cdk/schematics");
const terminal_1 = require("@angular-devkit/core/src/terminal");
const ng_ast_utils_1 = require("@schematics/angular/utility/ng-ast-utils");
// import { WorkspaceProject, WorkspaceSchema } from '@angular-devkit/core/src/workspace';
// import { red, yellow, bold } from '@angular-devkit/core/src/terminal';
// You don't have to export the function as default. You can also have more than one rule factory
// per file.
function ngAdd(options) {
    return schematics_1.chain([
        addDependencies(),
        addBrowserIgnorePackageSetting(),
        addCdkOverlayPrebuiltCssToAppStyles(options),
        addNgxFaceApiJsModule(options),
    ]);
}
exports.ngAdd = ngAdd;
function addDependencies() {
    return (host, context) => {
        const buf = host.read('package.json');
        if (!buf) {
            throw new schematics_1.SchematicsException('cannot find package.json');
        }
        const content = JSON.parse(buf.toString('utf-8'));
        content.dependencies = Object.assign({}, content.dependencies, { 'face-api.js': '^0.19.0' });
        content.devDependencies = Object.assign({}, content.devDependencies, { '@angular/cdk': 'latest' });
        host.overwrite('package.json', JSON.stringify(content, null, 2));
        context.addTask(new tasks_1.NodePackageInstallTask());
        return host;
    };
}
exports.addDependencies = addDependencies;
function addBrowserIgnorePackageSetting() {
    return (host, _) => {
        const buf = host.read('package.json');
        if (!buf) {
            throw new schematics_1.SchematicsException('cannot find package.json');
        }
        const content = JSON.parse(buf.toString('utf-8'));
        content.browser = Object.assign({}, content.browser, { fs: false, crypto: false });
        host.overwrite('package.json', JSON.stringify(content, null, 2));
        return host;
    };
}
function addNgxFaceApiJsModule(options) {
    return (host) => {
        const workspace = config_1.getWorkspace(host);
        const project = schematics_2.getProjectFromWorkspace(workspace, options.project);
        const appModulePath = ng_ast_utils_1.getAppModulePath(host, schematics_2.getProjectMainFile(project));
        const ngxFaceApiJsModuleName = 'NgxFaceApiJsModule';
        if (schematics_2.hasNgModuleImport(host, appModulePath, ngxFaceApiJsModuleName)) {
            return console.warn(terminal_1.red(`Could not set up "${terminal_1.bold(ngxFaceApiJsModuleName)}" ` +
                `because "${terminal_1.bold(ngxFaceApiJsModuleName)}" is already imported.`));
        }
        const modelsUrl = 'https://raw.githubusercontent.com/justadudewhohacks/face-api.js/master/weights';
        schematics_2.addModuleImportToRootModule(host, `NgxFaceApiJsModule.forRoot({ modelsUrl: '${modelsUrl}' })`, 'ngx-face-api-js', project);
        return host;
    };
}
function addCdkOverlayPrebuiltCssToAppStyles(options) {
    return (host, _) => {
        const workspace = config_1.getWorkspace(host);
        const project = schematics_2.getProjectFromWorkspace(workspace, options.project);
        const styleFilePath = schematics_2.getProjectStyleFile(project);
        if (!styleFilePath) {
            console.warn(terminal_1.red(`Could not find the default style file for this project.`));
            console.warn(terminal_1.red(`Please consider manually setting up the Roboto font in your CSS.`));
            return;
        }
        const buffer = host.read(styleFilePath);
        if (!buffer) {
            console.warn(terminal_1.red(`Could not read the default style file within the project ` +
                `(${terminal_1.italic(styleFilePath)})`));
            console.warn(terminal_1.red(`Please consider manually setting up the Robot font.`));
            return;
        }
        const content = buffer.toString();
        const insertion = '\n@import \'~@angular/cdk/overlay-prebuilt.css\';';
        if (content.includes(insertion)) {
            return;
        }
        const recorder = host.beginUpdate(styleFilePath);
        recorder.insertLeft(content.length, insertion);
        host.commitUpdate(recorder);
        return host;
    };
}
exports.addCdkOverlayPrebuiltCssToAppStyles = addCdkOverlayPrebuiltCssToAppStyles;
//# sourceMappingURL=index.js.map