"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const testing_1 = require("@angular-devkit/schematics/testing");
const test_1 = require("@schematics/angular/utility/test");
const path = require("path");
const config_1 = require("@schematics/angular/utility/config");
const schematics_1 = require("@angular/cdk/schematics");
const ng_ast_utils_1 = require("@schematics/angular/utility/ng-ast-utils");
const collectionPath = path.join(__dirname, '../collection.json');
function createTestApp(appOptions = {}) {
    const baseRunner = new testing_1.SchematicTestRunner('schematics', collectionPath);
    const workspaceTree = baseRunner.runExternalSchematic('@schematics/angular', 'workspace', {
        name: 'workspace',
        version: '7.1.2',
        newProjectRoot: 'projects',
    });
    return baseRunner.runExternalSchematic('@schematics/angular', 'application', Object.assign({}, appOptions, { name: 'example-app' }), workspaceTree);
}
describe('ngx-face-api-js-schematics', () => {
    it('addDependencies works', () => {
        const runner = new testing_1.SchematicTestRunner('schematics', collectionPath);
        const tree = runner.runSchematic('ng-add', {}, createTestApp());
        expect(tree.files).toContain('/package.json');
        const packageJson = JSON.parse(test_1.getFileContent(tree, '/package.json'));
        expect(packageJson.devDependencies['@angular/cdk']).toBe('latest');
        expect(packageJson.dependencies['face-api.js']).toBe('^0.19.0');
    });
    it('addBrowserIgnorePackageSetting works', () => {
        const runner = new testing_1.SchematicTestRunner('schematics', collectionPath);
        const tree = runner.runSchematic('ng-add', {}, createTestApp());
        expect(tree.files).toContain('/package.json');
        const packageJson = JSON.parse(test_1.getFileContent(tree, '/package.json'));
        expect(packageJson.browser.fs).toBe(false);
        expect(packageJson.browser.crypto).toBe(false);
    });
    it('addCdkOverlayPrebuiltCssToAppStyles works', () => {
        const runner = new testing_1.SchematicTestRunner('schematics', collectionPath);
        const tree = runner.runSchematic('ng-add', {}, createTestApp());
        const workspace = config_1.getWorkspace(tree);
        const project = schematics_1.getProjectFromWorkspace(workspace);
        const styleFilePath = schematics_1.getProjectStyleFile(project);
        if (styleFilePath) {
            const stylesScss = test_1.getFileContent(tree, styleFilePath);
            expect(stylesScss).toMatch('@import \'~@angular/cdk/overlay-prebuilt.css\'');
        }
    });
    it('addNgxFaceApiJsModule works', () => {
        const runner = new testing_1.SchematicTestRunner('schematics', collectionPath);
        const tree = runner.runSchematic('ng-add', {}, createTestApp());
        const workspace = config_1.getWorkspace(tree);
        const project = schematics_1.getProjectFromWorkspace(workspace);
        const appModulePath = ng_ast_utils_1.getAppModulePath(tree, schematics_1.getProjectMainFile(project));
        if (appModulePath) {
            const appModuleContent = test_1.getFileContent(tree, appModulePath);
            expect(appModuleContent).toMatch('NgxFaceApiJsModule.forRoot');
        }
    });
});
//# sourceMappingURL=index.spec.js.map